# -*- coding: cp1252 -*-
'''Assignment for the ecohydrology 450014 course to process
meteorology data from Twente and Portugal field courses.'''

'''
Please read all comments very well!

This is a multiline comment. coments should not exceed column 75. 
The script uses the meteolib and evaplib modules.
Download from http://ecohydro.falw.vu.nl.
This comment spans four lines.

Note that if a line gets too long (more than 75 characters) you
can use \ and continue at the next line, this will then be seen
as a single line
'''

# This is a one-line comment

__author__ = "Maarten J. Waterloo <maarten.waterloo@falw.vu.nl>"
__version__ = "2.0"
__date__ = "November 2014"


# *************************************************************************
# Q0: This script is for practising by students for analysing and
# displaying measured time series data.
#
# Throughout this script you will find comments (''' or #), statements and
# questions indicated by #Q1: - Q21:. Please go through this script very
# carefully, follow instructions and answer the questions.
#
# You are advised to read the python manual that is available at
# http://ecohydro.falw.vu.nl. It prepares you for this assignment.
# *************************************************************************

# NOTE: We will print some lines to indicate progress of the
# script at every step. This is done with the "print" statement
# as shown below for the start of the script...
#
# A lot of the statements have been commented out (#) in this
# script so that you can run it while you proceed and see the 
# results without error messages. This means that you will have
# to uncomment relevant statements in order to proceed.
#
print('\nScript started...\n')

# Import useful python modules
import os    # operating system routines
import scipy # Scientific Python functions
import pylab # Plotting functions
import matplotlib.dates # get date plotting functions
import datetime # get date functions
import time # for additional time functions

print('Standard modules imported...\n')

# *************************************************************************
# Q1: Explain what the purpose is of importing modules in # python?
# *************************************************************************
#
#
#
#
#

'''
Python needs to know where your files are located. 
Define your working directory as the variable workdir. This directory
is where you hold your own modules (meteolib.py and evaplib.py, download from
http://ecohydro.falw.vu.nl/python) your python script files, your data
files, etc. We use the variable "workdir" here, but any other name would
also do. Uncomment/change the appropriate statement below).
'''
# For Windows OS 
#workdir = 'drive_name:/your_name/ecohydrology/pyscripts'
#workdir = 'g:/smith/ecohydrology/pyscripts'
#
# For Linux/Unix OS
workdir = '/media/sony_ntfs/vu/courses/450014_ecohydrology/450014_assignments\
/python_assignment/pyscripts'

# Change to your assigned work directory using the chdir() function 
# from the os module (uncomment statement below)
#
#os.chdir(workdir)

print('Working directory assigned...\n')


'''
Import the modules with meteo functions, download the latest
versions from http://python.hydrology-amsterdam.nl. The meteolib.py and
evaplib.py files should be saved in the same directory as where you
have saved this script. Alternatively you could install them in the system.
'''
import meteolib             # Import functions from meteolib
import evaplib              # Import functions from evaplib

# *************************************************************************
# Q2: What functions are defined in meteolib and in evaplib? Use the help
# function, or just open the .py files with the corresponding names to find
# out... You can also visit the web pages for these modules at:
# http://python.hydrology-amsterdam.nl/moduledoc/index.html
# *************************************************************************
#
#
#
#
print('Meteolib and evaplib modules imported...\n')

# Statements below are needed to activate LaTeX interpretation
# for plotting using the pylab module.
# This allows you to use symbols and equations in plot labels
# Latex (www.miktex.org) should be installed on your computer to use this 
pylab.rc('text', usetex=True)

# Change default settings for figures
newdefaults = {'fontname':    'Arial',  # Use Arial font
               'backend':       'png',  # Save figure as PNG file   
               'axes.labelsize':   14,  # Axis label size in points
               'text.fontsize':    14,  # Text size in points
               'legend.fontsize':  12,  # Legend label size in points
               'xtick.labelsize':  14,  # x-tick label size in points
               'ytick.labelsize':  14,  # y-tick label size in points
               'lines.markersize': 10,  # markersize, in points
               'lines.linewidth':   1.5 # line width in points
               }
pylab.rcParams.update(newdefaults)

# Assign your data file name to the variable "datafile",
# The Campbell CR1000 datalogger program creates a data
# file called slowtable.dat
# use correct directory prefix if needed!
datafile = '../data/slowtable.dat'

'''
Below we shall import data into a variable called "meteodata", for which
we shall use the scipy.genfromtxt() function. This will be done as
datavar = scipy.genfromtxt(filename, **kwargs) where kwargs (key word arguments)
will be a dictionary (dict) variable to store any options that we want to pass
to the scipy.genfromtxt() function. The ** before kwargs makes sure that we
unpack the keyword options from the dictionary. One of these options allows us to specify
the name and data type that we want to assign to each column. We put these in a
variable col_headers first.

An alternative would be to use the scipy.loadtxt() function.
'''
# *************************************************************************
# Q3: Please first check how comments are indicated in the text file and
# what kind of delimiter is used. Usual delimitsigns are ' ' for space
# delimited file, ',' for comma delimited file and '\t' for tab delimited
# file. Comments in a text file are usually indicated by '#' or ';'
# characters starting a line.
# The converters option (not used here) allows you to convert a
# value/character string during the import of the data.
# The headers given in the data file are used to name variables that we
# import. 
# *************************************************************************

# List the column header names and their types
col_headers = [('TIMESTAMP','|S21'),('RECORD','<i8'),('PortStat2_Avg','<i8'),\
               ('BattV_Avg','<f8'),('PTemp_C_Avg','<f8'),('TCair_C_Avg','<f8'),\
               ('AvgTCa_Avg','<f8'),('stdTCa_Avg','<f8'),('Tair_C_Avg','<f8'),\
               ('RH_Avg','<f8'),('Tsoil_C1_Avg','<f8'),('Tsoil_C2_Avg','<f8'),\
               ('U_ms_S_WVT','<f8'),('WindDir_D1_WVT','<f8'),\
               ('WindDir_SD1_WVT','<f8'),('Rs_Wm2_Avg','<f8'),('Rn_mV_Avg','<f8'),\
               ('Rn_Wm2_Avg','<f8'),('Rncor_Wm2_Avg','<f8'),\
               ('airpress_hpa_Avg','<f8'),('Rain_mm_Tot','<f8'),('PA_uS_15','<f8'),\
               ('theta_15','<f8'),('PA_uS_45','<f8'),('theta_45','<f8'),\
               ('PA_uS_75','<f8'),('theta_75','<f8'),('druck_gwl_hPa_Avg','<f8')]

#This dictionary variable holds the options
kwargs = dict(delimiter=',',\
              deletechars=' ',\
              dtype=col_headers,\
              skip_header=4,\
              skip_footer=0,\
              filling_values='NaN',\
              missing_values={'\"NAN\"'}\
              )

# Now import the data to the variable meteodata
meteodata = scipy.genfromtxt(datafile, **kwargs)

# *************************************************************************
# Q4: What do the deletechars, skip_header and missing_values options
# mean in the statement above? What kind of variable type is stored in
# TIMESTAMP?
# You can access this variable by typing the variable name meteodata in the
# console, the last line lists names and data types.
# *************************************************************************
#
#
#
#
#

print('Data file loaded...\n')

# To convert TIMESTAMP we need to convert it to date/time that we
# can use for plotting

#Create arrays filled with zeros and proper length
YY = scipy.zeros(len(meteodata['TIMESTAMP']))
MM = scipy.zeros(len(meteodata['TIMESTAMP']))
DD = scipy.zeros(len(meteodata['TIMESTAMP']))
HH = scipy.zeros(len(meteodata['TIMESTAMP']))
mm = scipy.zeros(len(meteodata['TIMESTAMP']))
ss = scipy.zeros(len(meteodata['TIMESTAMP']))
numdatetime = scipy.zeros(len(meteodata['TIMESTAMP']))
# Create emty array
dateval = []

#Convert string date values to date and time values
for i in range (0,len(meteodata['TIMESTAMP']),1):
    datestring = meteodata['TIMESTAMP'][i]
    YY[i] = int(datestring[1:5])
    MM[i] = int(datestring[6:8])
    DD[i] = int(datestring[9:11])
    HH[i] = int(datestring[12:14])
    mm[i] = int(datestring[15:17])
    ss[i] = int(datestring[18:20])
    #create a datetime object holding dates and times
    dt = datetime.datetime(int(YY[i]),int(MM[i]),int(DD[i]),int(HH[i]),
                                int(mm[i]),int(ss[i]))
    dateval.append(dt)
    #create a numerical date value
    numdatetime[i]=matplotlib.dates.date2num(dt)
    
# get doy of year numbers
doy = scipy.zeros(len(meteodata['TIMESTAMP']))
for i in range (0,len(meteodata['TIMESTAMP']),1):
    doy[i] = int(datetime.date.fromordinal(int(numdatetime[i])).strftime("%j"))

# *************************************************************
# Q5: What is the purpose of the statements below...?
# Check if these are correct and uncomment all and
# complete those that are not complete.
# *************************************************************
#
recordnum = meteodata['RECORD']
portstat2 = meteodata['PortStat2_Avg']
battvolt = meteodata['BattV_Avg']
Tpanel =  meteodata['PTemp_C_Avg'] # [C]
TCair_avg = meteodata['TCair_C_Avg'] # [C]
TCavg_avg = meteodata['AvgTCa_Avg'] # [C]
#TCstd =  # [C]
#Tvais =  # [C]
#RHvais = # [%]
#TCsoil1 =  # [C]
#TCsoil2 =  # [C]
#U =  # [m/s]
#D =  # [N]
#stdD =  # [N]
Rs = meteodata['Rs_Wm2_Avg'] # [W/m2]
Rn = meteodata['Rncor_Wm2_Avg'] # [W/m2]
#airpress =  # [hPa]
#P =  # [mm]
#Pa_us15 =  # [us]
#theta_15 =  # [%]
#Pa_us45 =  # [us]
#theta_45 =  # [%]

print('Data assigned...\n')


# *************************************************************************
# Q7: You always need to check the quality of your data. Nighttime Rs
# radiation values may be negative or positive small values, but should be
# zero, correct this by inserting a statement below. There are a number
# of ways to do this. Check the nighttime Rs values in your data to decide
# on a limit.
#
# Tip: use the pylab.find() function, defined in the pylab module,
# to do this, or work straight with the array indices, or use a for
# statement to change this. Explain in words what you do.
# *************************************************************************
#


'''Now let us make the first plots that we will use to describe
the weather conditions in the study period'''

# Create figure 1: half-hourly values plot
pylab.figure(1)
# Clear the figure
pylab.clf()
# Make first subplot of three with radiation
pylab.subplot(311)
# Assign an Y-axis label
# See explanation about Latex label formatting in python for hydrologists
# manual! 
pylab.ylabel(r'${\rm Radiation~[W~m}^{-2}{\rm]}$')
# Plot Rn and Rs versus dec_time
pylab.plot_date(numdatetime, Rn, '+b', label= r'$R_n$', linewidth=1.5, markersize=4)
pylab.plot_date(numdatetime, Rs, '-r', label= r'$R_s$', linewidth=1.5, markersize=2)
# Create a legend at location 1 in graph, every corner has a number 1-4
pylab.legend(loc=1)
# Make second subplot with temperatures
pylab.subplot(312)
# Assign an Y-axis label
pylab.ylabel(r'${\rm Temperature~}[^\circ {\rm C]}$')
# Plot Rn and Rs versus dec_time
#pylab.plot(datevalue,TCavg, label= r'$T_{\rm air}$', color='r', linewidth=1.5)
pylab.legend()
# Make third subplot with soil temperatures
pylab.subplot(313)
# Assign an X-axis label
pylab.xlabel(r'${\rm Date}$')
# Assign an Y-axis label
pylab.ylabel(r'${\rm Rel.~humidity~[\%]}$')
#plot(datevalue,RHvais, label = '$Relative humidity$', linewidth=1.5)
pylab.legend()
# Save the figure as a .png file in the images directory of your report
# with ../ you go up one directory level
pylab.savefig('../report/images/metvar1.png',dpi=300)

print('First figure created...\n')


# *************************************************************
# Q8: Create figure 2: Wind speed, direction and soil
# temperatures, see above for how to do this
# *************************************************************
#
pylab.figure(2)
# Make first subplot with wind speed



# Make second subplot with wind direction



# Make third subplot with soil temperatures



# Save the plot in our reportimages directory for inserting in our report 
#savefig('../report/images/metvar2.png',dpi=300)

print('Second figure created...\n')


# Create figure 3: Rainfall, soil moisture and barometric pressure
pylab.figure(3)
# Make first subplot with rainfall and soil moisture content
pylab.subplot(211)
pylab.ylabel(r'$ \theta {\rm ~[\%}{\rm]}$')
#plot(datevalue,theta, label='soil moisture content',linewidth=1.5)
pylab.legend()
# Make second subplot with barometric pressure
pylab.subplot(212)
pylab.xlabel(r'${\rm DOY~2008}$')
pylab.ylabel(r'${\rm Barometric~pressure~[hpa]}$')
#plot(datevaleu,airpress, label = 'Barometric pressure', linewidth=1.5, color='r')
pylab.legend(loc=2)
# Save the plot in our reportimages directory for inserting in our report 
pylab.savefig('../report/images/metvar3.png',dpi=300)

print('Third figure created...\n')

'''
We have a description of the weather and now we are going to calculate
actual evaporation on a half-hourly basis using the TVEB method
'''
# Determine meteorological 'constants' using meteolib functions

# *************************************************************************
# Q9: Convert air pressure [hpa] to [Pa] by inserting a statement below
# (needed for meteorological function unit convention) and calculate rho,
# cp and lambda (use meteolib module functions)
# *************************************************************************

# Convert air pressure units
#airpress =     # [Pa]

# Calculate rho, cp and lambda
#rho = 
#cp = 
#Lambda =

print('Rho, Cp and Lambda calculated using meteolib functions...\n')


# For the procedure to calculate the soil heat flux [W/m2],
# check pages 31-32 from the reader. We need to estimate the
# thermal conductivity (lambda, Ls) for a sandy soil.
#
# *************************************************************************
# Q10: Explain how we calculate the soil heat flux with the two statements
# below, how is theta used to calculate Ls and what do the values of 0.3,
# 1.9, 33 and 2 in the equation represent? Uncomment the statements to
# calculate G.
# *************************************************************************
#
# 
#
#
#
#Ls = 0.3+1.9/33*(theta-2)
#G = Ls*(TCsoil1-TCsoil3)/0.02 # [W/m2]

print('Soil heat flux calculated...\n')


''' Calculate the sensible heat flux H [W/m2] using the temperature
variance energy balance method'''

# Define some constant here first
g = 9.81 # [m/s2]
z = 2.6 # [m]
d = 0.0 # [m]

# Create an array of the appropriate length to store half-hourly H-values
#H=scipy.zeros(len(cp))

# *************************************************************************
# Q11. Now calculate H from the temperature variance equation as
# described by Eq. 2.3 in the assignment manual [W/m2]
# Also calculate the latent heat flux LE [W/m2] using the
# energy balance equation. Then convert LE from [W/m2] to mm
# per half hour (use variable name LEmm)
# *************************************************************************
#
# H=

print('Sensible heat flux calculated...\n')


#LE =
#LEmm =

print 'Latent heat flux calculated...\n'



# *************************************************************************
# Q12: Explain what the code from startdate = ...
# until dsumP =  scipy.array(dsumP) does and what the sequence of
# steps is to achieve its purpose. Extend the code
# to include the maximum and minimum daily windspeed values?
# *************************************************************************

# Determine start and end days as Julian days (day of year)
startdate = datetime.date.fromordinal(int(numdatetime[0])) # first value in array
enddate =  datetime.date.fromordinal(int(numdatetime[-1])) # last value in array
startday = int(startdate.strftime('%j'))
endday = int(enddate.strftime('%j'))


# Define empty arrays for holding the daily data
dayno = []
davgRn = []
davgRs = []
davgRH = []
davgT = []
dmaxT = []
dminT = []
davgpress = []
davgTsoil1 = []
davgTsoil3 = []
davggwl = []
davgtheta = []
davgU = []
davgD = []
dsumP = []

# Determine daily averages and place these in arrays, uncomment
# the following (note: keep indentation correct!).

#for day in range(startday+1,endday):
    # Get indices for each day
#    dayindex = pylab.find(doy==day)
    # Append day to previous data 
#    dayno.append(day)
    # Calculate averages and append
#    avgRn = scipy.average(Rn[dayindex])
#    davgRn.append(avgRn)
#    avgRs = scipy.average(Rs[dayindex])
#    davgRs.append(avgRs)
#    avgRH = scipy.average(RHvais[dayindex])
#    davgRH.append(avgRH)
#    avgT = scipy.average(TCavg[dayindex])
#    davgT.append(avgT)
#    maxT = scipy.max(TCavg[dayindex])
#    dmaxT.append(maxT)
#    minT = scipy.min(TCavg[dayindex])
#    dminT.append(minT) 
#    avgpress = scipy.average(airpress[dayindex])
#    davgpress.append(avgpress)
#    avgTsoil1 = scipy.average(TCsoil1[dayindex])
#    davgTsoil1.append(avgTsoil1)
#    avgTsoil3 = scipy.average(TCsoil3[dayindex])
#    davgTsoil3.append(avgTsoil3)
#    avggwl =  scipy.average(gwl[dayindex])
#    davggwl.append(avggwl)
#    avgtheta = scipy.average(theta[dayindex])
#    davgtheta.append(avgtheta)
    # use meteolib.windvec() function to calculate average wind speed and
    # direction
#    avgU,avgD = meteolib.windvec(U[dayindex],D[dayindex])
#    davgU.append(avgU)
#    davgD.append(avgD)
#    sumP = scipy.sum(P[dayindex])
#    dsumP.append(sumP)
    
# The above produces lists, convert these lists to arrays
#davgRn = scipy.array(davgRn)
#davgRs = scipy.array(davgRs)
#davgRh = scipy.array(davgRH)
#davgT = scipy.array(davgT)
#dmaxT = scipy.array(dmaxT)
#dminT = scipy.array(dminT)
#davgpress =  scipy.array(davgpress)
#davgTsoil1 =  scipy.array(davgTsoil1)
#davgTsoil3 =  scipy.array(davgTsoil3)
#davggwl =  scipy.array(davggwl)
#davgtheta =  scipy.array(davgtheta)
#davgU =  scipy.array(davgU)
#davgD =  scipy.array(davgD)
#dsumP =  scipy.array(dsumP)

print('Daily averages and totals calculated...\n')


# Create figure 4: evaporation during the day
pylab.figure(4)
pylab.clf()
# Make first plot
pylab.subplot(311)
pylab.ylabel(r'${\rm Evaporation~[W~m}^{-2}{\rm ]}$')
#pylab.plot(dayno,davgRn, label= r'$R_n$', linewidth=1.5)
#pylab.plot(dayno,davgRs, label = r'$R_s$', linewidth=1.5)
pylab.legend()
# Make second subplot
pylab.subplot(312)
pylab.ylabel(r'${\rm Temperature~}[^\circ {\rm C]}$')
#pylab.plot(dayno,davgT, label= r'$T_{\rm air}$', linewidth=1.5)
#pylab.plot(dayno,davgTsoil1, label = r'$T_{{\rm soil}}{\rm ~at -0.01 m}$', linewidth=1.5)
#pylab.plot(dayno,davgTsoil3, label = r'$T_{{\rm soil}}{\rm ~at -0.03 m}$', linewidth=1.5)
pylab.legend()
# Make third subplot
pylab.subplot(313)
pylab.xlabel(r'${\rm DOY~2008}$')
pylab.ylabel(r'$\theta {\rm ~[\%]~and~P~[mm]}$')
#pylab.plot(dayno,davgtheta, label= r'$\theta$', linewidth=1.5)
#pylab.plot(dayno,dsumP, label= r'$P$', linewidth=1.5)
pylab.legend()
pylab.savefig('../report/images/metvar4.png',dpi=300)
print('Fourth figure created...\n')

# Create figure 5: daily averages
pylab.figure(5)
pylab.clf()
pylab.ylabel(r'${\rm Wind~speed~[m~s}^{-1}{\rm ]}$')
#pylab.plot(dayno,davgU, label= r'$U$', linewidth=1.5)
pylab.legend(loc=2)
pylab.twinx()
pylab.ylabel(r'${\rm Wind~direction~[}^{\circ}{\rm ]}$')
#pylab.plot(dayno,davgD, label = r'$D$', linewidth=1.5,color='r')
pylab.legend(loc=1)
pylab.xlabel(r'${\rm DOY~2008}$')
pylab.savefig('../report/images/metvar5.png',dpi=300)
print('Fifth plot created')


''' Calculate daily sum of LEmm, note that we cannot
include nighttime data in the total, so we have to sum
data from when it is light (for instance between 8:00 h
and 19:00 h). Alternatively, we could also use a certain
value of Rs (for instance >50 W m-2) to define daytime.'''
# First select all values for a single day. Insert times of dusk and dawn
# in Portugal into the statements below to get the correct daytime sum of
# LE (store in variable sumLEmm).

#sunrise = # [h]
#sunset =  # [h]

#
# *************************************************************************
# Q13: Uncomment the following for statements and explain how it gives
# you the sum of values between set times for every day of the data record.
# Why do we use startday+1, what does the & operator do?
# *************************************************************************
#

# Define an array for storing calculated daily LE values
dsumLEmm = []
#for day in range(startdate+1,enddate):
    # Make variable to store the summed values and set to zero
#    sumLEmm = 0.0
    # find the correct indices for each day between the selected sunrise/sunset
#    dayindex = pylab.find((numdatetime > day + sunrise/24.) & (numdatetime < day + sunset/24.))
#    sumLEmm = sum(LEmm[dayindex])
    # Append the total to the dsumLEmm list
#    dsumLEmm.append(sumLEmm)


# Create figure 6, Eact
pylab.figure(6)
pylab.clf()
# Make sixth plot
pylab.ylabel(r'${\rm Radiation~[W~m}^{-2}{\rm ]}$')
#pylab.plot(dayno,davgRn,'r', label= r'$R_n$', linewidth=1.5)
pylab.legend(loc=2)
pylab.twinx()
pylab.ylabel(r'${\rm Evaporation~[mm]}$')
#pylab.plot(dayno,dsumLEmm, label = r'$E_{act}$', linewidth=1.5)
pylab.legend(loc=1)
pylab.xlabel(r'${\rm DOY~2008}$')
pylab.savefig('../report/images/dailyeact.png',dpi=300)
print('Sixth plot created')


''' Penman open water and Makkink reference evaporation...
We use the averages calculated before for this... Use E0
and Makkink Em functions from evaplib library'''

# 
#
# *************************************************************************
# Q14: Insert the correct statements below to do this:
# - Convert daily average incoming radiation [W m-2] to J/m2/day
# - Get daylenght N and extraterrestrial radiation Rext. What is the
# latitude of Vagos, North Portugal near Aveiro? Insert the latitude
# (in degrees) in the statement below?
# - Calculate Penman open water evaporation and Makkink evaporation
# - Calculate crop factor f based on Makkink evaporation
# *************************************************************************
#
#dtotRs =
#
#latitude =

#N,Rext = meteolib.sun_NR(dayno,latitude)

#E0 = evaplib.E0(davgT,davgRH,davgpress,dtotRs,Rext,davgU)

#Em = 

#f =


#Calculate average E0, Ea and f and print these
# Uncomment lines below
#avgE = scipy.average(dsumLEmm)
#avgE0 = scipy.average(E0)
#avgEm = scipy.average(Em)
#avgf = scipy.average(f)

# *************************************************************
# Q15: What does '%5.2f'% do in the print command below? What 
# does the 5.2f stand for?
# *************************************************************

#print 'Average actual evaporation is: ','%5.2f'% avgE
#print 'Average Penman open water evaporation is: ','%5.2f'% avgE0
#print 'Average Makkink evaporation is: ','%5.2f'% avgEm
#print 'Average crop factor is: ','%5.2f'% avgf


pylab.figure(7)
pylab.clf()
# Make seventh plot
pylab.subplot(111)
pylab.ylabel(r'${\rm Heat~fluxes~and~Net~radiation~[W~m}^{-2}{\rm]}$')
#pylab.plot(dec_time,LE, label=r'$Latent~heat~flux$', linewidth=1.5)
#pylab.plot(dec_time,H, label=r'$Sensible~heat~flux$', linewidth=1.5)
#pylab.plot(dec_time,G, label=r'$Soil~heat~flux$', linewidth=1.5)
#pylab.plot(dec_time,Rn, label= r'$Net~radiation$', linewidth=1.5)
pylab.legend()
pylab.xlabel(r'${\rm HOUR~2008}$')
pylab.savefig('evaporation.png',dpi=300)


# *************************************************************
# Q16: Convert Em from mm day-1 to W m-2 (variable Em_wm) for
# plotting together with the above variables...
# *************************************************************

#Em_wm

#pylab.plot(dayno,Em_wm, 'k:', label=r'$E_m$', linewidth=1.5)
pylab.legend(loc=1)
pylab.twinx()
pylab.ylabel(r'${\rm Crop factor}$')
#pylab.plot(dayno,f,'r', label = 'Crop factor', linewidth=1.5)
pylab.legend(loc=2)
pylab.xlabel(r'${\rm HOUR~2008}$')
pylab.savefig('evaporation2.png',dpi=300)

print('Seventh plot created')





# Copyright M.J. Waterloo, November 2014.
